# Branding

## Name

This project is named **kr8s** (pronounced the same as *"crates"*).

Kubernetes is often shortened to the numeronym *k8s* (the middle 8 letters are replaced with the letter 8), however some people pronounce this as *k-eight-s* or *k-ate-s*.

The project is written in Python so projects often have a snake theme and a *Krait* is a type of sea snake.

The name **kr8s** is a combination of *"k8s"* and *"Kraits"*.

## Logo

The logo was designed by [alex_creations9](https://www.fiverr.com/alex_creations9). All assets and design files can be found in the [branding directory](https://github.com/kr8s-org/kr8s/tree/main/branding).

![](_static/branding/logo.png)

![](_static/branding/logo-alt.png)

![](_static/branding/logo-wide.png)

![](_static/branding/text-trimmed.png)
